slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPConvergedReasonViewFromOptions

Processes command line options to determine if/how the PEP converged reason is to be viewed.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPConvergedReasonViewFromOptions(PEP pep)

Collective on pep

### Input Parameter

| pep | - the eigensolver context

### See Also

PEPConvergedReasonView()

### Level

developer

### Location

src/pep/interface/pepview.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages